@@ -32,4 +32,15 @@ f10_indicator = "https://stock.xueqiu.com/v5/stock/f10/cn/indicator.json?symbol=
 
 # real time
 realtime_quote = "https://stock.xueqiu.com/v5/stock/realtime/quotec.json?symbol="
-realtime_pankou = "https://stock.xueqiu.com/stock/pankou.json?symbol="
+realtime_pankou = "https://stock.xueqiu.com/v5/stock/realtime/pankou.json?symbol="
+
+#user
+watch_list = "https://stock.xueqiu.com/v5/stock/portfolio/list.json?system=true"
+watch_stock = "https://stock.xueqiu.com/v5/stock/portfolio/stock/list.json?size=1000&category=1&pid="
+
+#cube
+nav_daily = "https://xueqiu.com/cubes/nav_daily/all.json?cube_symbol="
+rebalancing_history = "https://xueqiu.com/cubes/rebalancing/history.json?cube_symbol="
+
+# quote detail
+quote_detail = "https://stock.xueqiu.com/v5/stock/quote.json?symbol=%s&extend=detail"
